@@ -6,10 +6,11 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 use Carp qw(confess cluck);
 use DateTime;
+use DateTime::Format::Strptime;
 use Encode qw(encode decode);
 use List::Util qw(first);
 use List::MoreUtils qw(uniq);
@@ -36,11 +37,17 @@ sub new {
 		iris_base      => $opt{iris_base}
 		  // 'http://iris.noncd.db.de/iris-tts/timetable',
 		lookahead => $opt{lookahead} // ( 4 * 60 ),
-		main_cache   => $opt{main_cache},
-		rt_cache     => $opt{realtime_cache},
-		serializable => $opt{serializable},
-		user_agent   => $ua,
-		with_related => $opt{with_related},
+		main_cache      => $opt{main_cache},
+		rt_cache        => $opt{realtime_cache},
+		serializable    => $opt{serializable},
+		user_agent      => $ua,
+		with_related    => $opt{with_related},
+		departure_by_id => {},
+		strptime_obj    => DateTime::Format::Strptime->new(
+			pattern   => '%y%m%d%H%M',
+			time_zone => 'Europe/Berlin',
+		),
+
 	};
 
 	bless( $self, $class );
@@ -62,6 +69,8 @@ sub new {
 			developer_mode => $self->{developer_mode},
 			lookahead      => $self->{lookahead},
 			station        => $ref->{uic},
+			main_cache     => $self->{main_cache},
+			realtime_cache => $self->{rt_cache},
 			with_related   => 0,
 		);
 		if ( not $ref_status->errstr ) {
@@ -249,14 +258,15 @@ sub add_result {
 	}
 
 	my %data = (
-		raw_id    => $id,
-		classes   => $e_tl->getAttribute('f'),    # D N S F
-		unknown_t => $e_tl->getAttribute('t'),    # p
-		train_no  => $e_tl->getAttribute('n'),    # dep number
-		type      => $e_tl->getAttribute('c'),    # S/ICE/ERB/...
-		line_no   => $e_tl->getAttribute('l'),    # 1 -> S1, ...
-		station   => $station,
-		unknown_o => $e_tl->getAttribute('o'),    # owner: 03/80/R2/...
+		raw_id       => $id,
+		classes      => $e_tl->getAttribute('f'),    # D N S F
+		unknown_t    => $e_tl->getAttribute('t'),    # p
+		train_no     => $e_tl->getAttribute('n'),    # dep number
+		type         => $e_tl->getAttribute('c'),    # S/ICE/ERB/...
+		line_no      => $e_tl->getAttribute('l'),    # 1 -> S1, ...
+		station      => $station,
+		unknown_o    => $e_tl->getAttribute('o'),    # owner: 03/80/R2/...
+		strptime_obj => $self->{strptime_obj},
 	);
 
 	if ($e_ar) {
@@ -292,8 +302,9 @@ sub add_result {
 	# if scheduled departure and current departure are not within the
 	# same hour, trains are reported twice. Don't add duplicates in
 	# that case.
-	if ( not first { $_->raw_id eq $id } @{ $self->{results} } ) {
+	if ( not $self->{departure_by_id}{$id} ) {
 		push( @{ $self->{results} }, $result, );
+		$self->{departure_by_id}{$id} = $result;
 	}
 
 	return $result;
@@ -350,9 +361,11 @@ sub get_realtime {
 
 		my %messages;
 
-		my $result = first { $_->raw_id eq $id } $self->results;
+		my $result = $self->{departure_by_id}{$id};
 
-		if ( not $result ) {
+		# add_result will return nothing if no ./tl node is present. The ./tl
+		# check here is for optimization purposes.
+		if ( not $result and ( $s->findnodes('./tl') )[0] ) {
 			$result = $self->add_result( $station, $s );
 			if ($result) {
 				$result->set_unscheduled(1);
@@ -536,7 +549,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
@@ -583,6 +596,14 @@ non-negative integer is accepted.
 Passed on to C<< LWP::UserAgent->new >>. Defaults to C<< { timeout => 10 } >>,
 you can use an empty hashref to unset the default.
 
+=item B<main_cache> => I<$ojj>
+
+A Cache::File(3pm) object used to cache station and timetable requests. Optional.
+
+=item B<realtime_cache> => I<$ojj>
+
+A Cache::File(3pm) object used to cache realtime data requests. Optional.
+
 =item B<station> => I<stationcode>
 
 Mandatory: Which station to return departures for. Note that this is not a
@@ -640,7 +661,7 @@ None.
 
 =head1 BUGS AND LIMITATIONS
 
-Many backend features are not yet exposed.
+Some backend features are not yet exposed.
 
 =head1 SEE ALSO
 
