@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -116,7 +116,7 @@ sub new {
 
 	bless( $ref, $obj );
 
-	$ref->{strptime_obj} = DateTime::Format::Strptime->new(
+	$ref->{strptime_obj} //= DateTime::Format::Strptime->new(
 		pattern   => '%y%m%d%H%M',
 		time_zone => 'Europe/Berlin',
 	);
@@ -745,7 +745,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 DESCRIPTION
 
