@@ -62,11 +62,13 @@ while ( my $line = <STDIN> ) {
 	$station =~ s{ ^ EDO \s N $ }{EDO}x;
 	$station =~ s{ ^ FBUSS    $ }{FBUS}x;
 	$station =~ s{ ^ FH \s\s N$ }{FH}x;
+	$station =~ s{ ^ FMTN     $ }{FMT}x;
 	$station =~ s{ ^ KAREP    $ }{KARE}x;
 	$station =~ s{ ^ KBR \s P $ }{KBR}x;
 	$station =~ s{ ^ KDDH     $ }{KDD}x;
 	$station =~ s{ ^ KDFFH    $ }{KDFF}x;
 	$station =~ s{ ^ KDN \s P $ }{KDN}x;
+	$station =~ s{ ^ KGKK     $ }{KGEK}x;
 	$station =~ s{ ^ KRY \s P $ }{KRY}x;
 	$station =~ s{ ^ TS \s\s T$ }{TST}x;
 	$station =~ s{ ^ TSZ \s F $ }{TSFE}x;
@@ -1858,6 +1860,12 @@ sub get_station {
 		return ($ds100_match);
 	}
 
+	my $eva_match = firstval { defined $_->[2] and $name eq $_->[2] } @stations;
+
+	if ($eva_match) {
+		return ($eva_match);
+	}
+
 	return get_station_by_name($name);
 }
 
@@ -1888,7 +1896,6 @@ sub get_station_by_location {
 	return @station_map;
 }
 
-
 sub get_station_by_name {
 	my ($name) = @_;
 
@@ -1986,11 +1993,11 @@ Returns a list of all known stations, lexically sorted by station name.
 
 Returns a list of stations matching I<$in>.
 
-If a I<$in> is a valid station code, only one element ([I<$in>, related name])
-is returned. Otherwise, it is passed to get_station_by_name(I<$in>) (see
-below).
+If a I<$in> is a valid station (either DS100 code or UIC/EVA number),
+a single array reference describing the station is returned. Otherwise,
+I<$in> is passed to get_station_by_name(I<$in>) (see below).
 
-Note that station codes matching is case sensitive and must be exact.
+Note that DS100 code matching is case sensitive.
 
 =item Travel::Status::DE::IRIS::Stations::get_station_by_location(I<$lon>, I<$lat>, I<$num_matches>)
 
